pywr.recorders.AggregatedRecorder
=================================

.. currentmodule:: pywr.recorders

.. autoclass:: AggregatedRecorder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AggregatedRecorder.after
      ~AggregatedRecorder.aggregated_value
      ~AggregatedRecorder.before
      ~AggregatedRecorder.finish
      ~AggregatedRecorder.load
      ~AggregatedRecorder.register
      ~AggregatedRecorder.reset
      ~AggregatedRecorder.setup
      ~AggregatedRecorder.unregister
      ~AggregatedRecorder.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~AggregatedRecorder.agg_func
      ~AggregatedRecorder.children
      ~AggregatedRecorder.comment
      ~AggregatedRecorder.epsilon
      ~AggregatedRecorder.ignore_nan
      ~AggregatedRecorder.is_constraint
      ~AggregatedRecorder.is_objective
      ~AggregatedRecorder.model
      ~AggregatedRecorder.name
      ~AggregatedRecorder.parents
      ~AggregatedRecorder.recorders
   
   